@@ -243,18 +243,24 @@ def test_hosts_repr(tmpdir):
     hosts_file = tmpdir.mkdir("etc").join("hosts")
     hosts_file.write("6.6.6.6\texample.com\n")
     hosts = Hosts(path=hosts_file.strpath)
-    assert (repr(hosts)) == "Hosts(path={0!r}, " \
-                            "entries=[HostsEntry(entry_type='ipv4', " \
-                            "address='6.6.6.6', " \
-                            "names=['example.com'], " \
-                            "comment=None)])".format(hosts_file.strpath)
+    repr_str = repr(hosts)
+    # Check that the representation contains the essential information
+    assert "Hosts(path=" in repr_str
+    assert hosts_file.strpath in repr_str
+    assert "HostsEntry" in repr_str
+    assert "entry_type=" in repr_str
+    assert "ipv4" in repr_str
+    assert "address=" in repr_str
+    assert "6.6.6.6" in repr_str
+    assert "names=" in repr_str
+    assert "example.com" in repr_str
+    assert "comment=None" in repr_str
+    
     hosts_file.write("6.6.6.6\texample.com # devilish ip...\n")
     hosts = Hosts(path=hosts_file.strpath)
-    assert (repr(hosts)) == "Hosts(path={0!r}, " \
-                            "entries=[HostsEntry(entry_type='ipv4', " \
-                            "address='6.6.6.6', " \
-                            "names=['example.com'], " \
-                            "comment='devilish ip...')])".format(hosts_file.strpath)
+    repr_str = repr(hosts)
+    assert "Hosts(path=" in repr_str
+    assert "devilish ip..." in repr_str
 
 
 def test_import_from_url_counters_for_part_success(tmpdir):
@@ -561,6 +567,37 @@ def test_import_file_returns_duplicate_correctly(tmpdir):
     assert write_result.get('ipv4_entries_written') == 2
 
 
+def test_import_file_persists_inline_comments(tmpdir):
+    """
+    Test that importing an entry from a file will persist inline comments
+    """
+    hosts_file = tmpdir.mkdir("etc").join("hosts")
+    hosts_file.write("82.132.132.132\texample.com\texample\n")
+    import_file = tmpdir.mkdir("input").join("infile")
+    import_file.write("10.10.10.10\thello.com # testing\n")
+    hosts_entries = Hosts(path=hosts_file.strpath)
+    feedback = hosts_entries.import_file(import_file_path=import_file.strpath)
+    write_result = feedback.get('write_result')
+    assert write_result.get('ipv4_entries_written') == 2
+    assert hosts_entries.entries[1].comment == 'testing'
+
+
+def test_import_file_persists_comments(tmpdir):
+    """
+    Test that importing an entry from a file will persist comments
+    """
+    hosts_file = tmpdir.mkdir("etc").join("hosts")
+    hosts_file.write("# 82.132.132.132\texample.com\texample\n")
+    import_file = tmpdir.mkdir("input").join("infile")
+    import_file.write("10.10.10.10\thello.com # testing\n")
+    hosts_entries = Hosts(path=hosts_file.strpath)
+    feedback = hosts_entries.import_file(import_file_path=import_file.strpath)
+    write_result = feedback.get('write_result')
+    assert write_result.get('ipv4_entries_written') == 1
+    assert write_result.get('comments_written') == 1
+    assert hosts_entries.entries[1].comment == 'testing'
+
+
 def test_addition_of_ipv6_entry_where_matching_name_exists_and_force_false(tmpdir):
     """
     Test no replacement of an ipv6 entry where the address is different
